package ch.std.rest.upload.controller;

import java.nio.file.Path;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import ch.std.rest.upload.dto.RequestUploadDTO;
import ch.std.rest.upload.dto.ResponseUploadDTO;
import ch.std.rest.upload.service.FileService;


@RestController
@RequestMapping(path="/rest")
public class UploadController {

	Logger logger = LoggerFactory.getLogger(UploadController.class);

	private FileService fileService;

	public UploadController(FileService fileService) {
		this.fileService = fileService;
	}

	@PostMapping(path = "upload", produces = { MediaType.APPLICATION_JSON_VALUE })
	public ResponseUploadDTO uploadDokument(@RequestPart("file") MultipartFile file) {
		String fileName = file.getOriginalFilename();
		ResponseUploadDTO responseUploadDTO = new ResponseUploadDTO();
		try {
			Path out = this.fileService.save(fileName, file.getInputStream());
			responseUploadDTO.setSuccess("file uploaded");
			responseUploadDTO.setPath(out);
		} catch (Exception e) {
			responseUploadDTO.setFailed(e.getMessage());
		}
		return responseUploadDTO;
	}
	
	@PostMapping(path = "uploaddto", produces = { MediaType.APPLICATION_JSON_VALUE })
	public ResponseUploadDTO uploadDokumentWithDTO(@RequestPart("dto") RequestUploadDTO dto, @RequestPart("file") MultipartFile file) {
		String fileName = dto.getFileName();
		ResponseUploadDTO responseUploadDTO = new ResponseUploadDTO();
		try {
			Path out = this.fileService.save(fileName, file.getInputStream());
			responseUploadDTO.setSuccess("file uploaded");
			responseUploadDTO.setPath(out);
		} catch (Exception e) {
			responseUploadDTO.setFailed(e.getMessage());
		}
		return responseUploadDTO;
	}

}

